#!/usr/bin/env	python

########################################################################
#    Reads Preferences and Style files for the Claw3 Filebrowser
#    Copyright 2004, Gabe Ginorio <gabe@zevallos.com.br>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#######################################################################

import os, os.path, string, sys, shutil
from xml.dom import minidom
import gtk, gtk.gdk, pango


########################################################################
# This function reads the preferences file and set the appropriate variables
########################################################################
def getPreferences(Claw3):
	
	# Let's set the location of the install
	programPath = os.path.abspath(string.replace(sys.argv[0], "Claw3.py", "")) + "/"

	# First let's see if the file exists
	if not os.path.exists(os.environ['HOME'] + "/.claw/preferences3.xml"):
		try:
			# IF the ~/.claw/ directory is missing, make it
			if not os.path.exists(os.environ['HOME'] + "/.claw"):
				try:
					os.mkdir(os.environ['HOME'] + "/.claw")
				except:

					# If we can't make the .claw directory, then we have serious issues
					Claw3.infoBar.set_text("You don't have permission to write to you home directory?!! You need to seriously fix this.")
					return 1

			# If the preferences file is missing, copy the default one to ~/.claw/
			if os.path.exists(programPath + "preferences.xml"):
				shutil.copy(programPath + "preferences.xml", os.environ['HOME'] + "/.claw/preferences3.xml")
			else:
				Claw3.infoBar.set_text("I can't seem to find the preferences.xml file in the installation.")
				print "Can't get Preferences to work"
				return 1
		except:

			# If nothing works, we're screwed
			print "Cannot Open Preferences file, and I don't know why"
			return 1


	# Try to parse the preferences file (using the built-in python XML reader)
	try:
		preferencesFile = minidom.parse(os.environ['HOME'] + "/.claw/preferences3.xml")
	except:
		Claw3.infoBar.set_text("I can't open the ~/.claw/preferences3.xml file!")
		return 1

	# At this point, the preferences file is open, and we can extract information from it

	# Let's set a list of items we expect to find in the file
	preferenceItems = ["terminal", "clear_address", "image", "audio", "permissions", "archiver", 
			"font", "color", "background", "language"]
	
	# Make a list to hold the stuff we get from the file
	preferences = []

	# Get the information from the xml (DOM) tree
	for item in preferenceItems:
		node = preferencesFile.getElementsByTagName(item)
		preferences.append(node[0].childNodes[0].data)

	# Set the preferences and move on
	if cmp(preferences[0],'default'):
		Claw3.termType  = os.getenv('TERMCMD','xterm')
	else:  
		 Claw3.termType  = preferences[0]

	Claw3.clearAddress	= int(preferences[1])
	Claw3.previewImage	= preferences[2]
	Claw3.previewAudio	= preferences[3]
	Claw3.showPermissions	= preferences[4]
	Claw3.archiver		= preferences[5]
	Claw3.font		= pango.FontDescription(preferences[6])
	colors = string.split(preferences[7], ",")
	Claw3.fontColor		= gtk.gdk.Color(int(colors[0]), int(colors[1]), int(colors[2]), 0)
	colors = string.split(preferences[8], ",")
	Claw3.layoutColor	= gtk.gdk.Color(int(colors[0]), int(colors[1]), int(colors[2]), 0)
	Claw3.language = preferences[9]

########################################################################
# This function reads the translation file for the selected language
########################################################################
def getLanguage(Claw3, language):

	languageFile =minidom.parse(Claw3.programPath + "translations/" + language + ".trans")
	
	language = {}

	tags = languageFile.childNodes
	parentNodes = tags[2].childNodes
	parentNodes = filter(lambda node: string.strip(node.toxml()) != "", parentNodes)

	for nodes in parentNodes:
		nodes = filter(lambda node: string.strip(node.toxml()) != "", nodes.childNodes)
		for node in nodes:
			language[node.tagName] = [node.childNodes[0].data,  node.getAttribute("tip")]

	Claw3.messages=language
	
	
